@@ -3,9 +3,9 @@
 
 int main(int argc, char *argv[])
 {
-    QApplication::setOrganizationName("hschmitt");
-    QApplication::setApplicationName("profile-changer-widget");
-    QApplication::setApplicationVersion("0.4-5");
+//    QApplication::setOrganizationName("hschmitt");
+//    QApplication::setApplicationName("profile-changer-widget");
+//    QApplication::setApplicationVersion("0.4-5");
     syslog(LOG_WARNING, "Starting profile-changer-widget");
     // enforce native graphics system for now due to a bug in transparency handling
     // you can remove this line if you only target PR 1.2
@@ -20,9 +20,9 @@ int main(int argc, char *argv[])
 
     QMaemo5HomescreenAdaptor *adaptor = new QMaemo5HomescreenAdaptor(&w);
     syslog(LOG_WARNING, "profile-changer-widget settings");
-    adaptor->setSettingsAvailable(true);
+//    adaptor->setSettingsAvailable(false);
     syslog(LOG_WARNING, "profile-changer-widget settings connect");
-    QObject::connect(adaptor, SIGNAL(settingsRequested()), &w, SLOT(onShowSettingsDialog()));
+//    QObject::connect(adaptor, SIGNAL(settingsRequested()), &w, SLOT(onShowSettingsDialog()));
     syslog(LOG_WARNING, "profile-changer-widget show");
     w.show();
     syslog(LOG_WARNING, "profile-changer-widget app.exec");
