@@ -10,16 +10,16 @@ ProfileChangerWidget::ProfileChangerWidget(QWidget *parent) :
 {
     syslog(LOG_WARNING, "profile-changer-widget.cpp setupui");
     ui->setupUi(this);
-    this->setAttribute(Qt::WA_TranslucentBackground);
-    if (!QSettings().contains("profilechangerwidget/width"))
-        QSettings().setValue("profilechangerwidget/width", 48);
-    if (!QSettings().contains("profilechangerwidget/height"))
-        QSettings().setValue("profilechangerwidget/height", 48);
+//    this->setAttribute(Qt::WA_TranslucentBackground);
+//    if (!QSettings().contains("profilechangerwidget/width"))
+//        QSettings().setValue("profilechangerwidget/width", 48);
+//    if (!QSettings().contains("profilechangerwidget/height"))
+//        QSettings().setValue("profilechangerwidget/height", 48);
 
-    syslog(LOG_WARNING, "profile-changer-widget connect onChangeProfileClicked");
-    connect(ui->switchButton, SIGNAL(clicked()), this, SLOT(onChangeProfileClicked()));
-    syslog(LOG_WARNING, "profile-changer-widget connect reload");
-    this->reloadSettings();
+//    syslog(LOG_WARNING, "profile-changer-widget connect onChangeProfileClicked");
+//    connect(ui->switchButton, SIGNAL(clicked()), this, SLOT(onChangeProfileClicked()));
+//    syslog(LOG_WARNING, "profile-changer-widget connect reload");
+//    this->reloadSettings();
 }
 
 ProfileChangerWidget::~ProfileChangerWidget()
@@ -87,15 +87,15 @@ void ProfileChangerWidget::switchProfile() {
 }  
 
 void ProfileChangerWidget::onChangeProfileClicked() {
-    switchProfile();
-    refreshIcon();
+//    switchProfile();
+//    refreshIcon();
 }
 
 void ProfileChangerWidget::onShowSettingsDialog()
 {
-    SettingsDialog *dialog = new SettingsDialog(0);
-    connect(dialog, SIGNAL(settingsChanged()), this, SLOT(reloadSettings()));
-    dialog->show();
+//    SettingsDialog *dialog = new SettingsDialog(0);
+//    connect(dialog, SIGNAL(settingsChanged()), this, SLOT(reloadSettings()));
+//    dialog->show();
 }
 
 void ProfileChangerWidget::reloadSettings()
