@@ -1,7 +1,6 @@
-#ifndef _PROFILECHANGERWIDGET_H_
-#define _PROFILECHANGERWIDGET_H_
+#ifndef PROFILECHANGERWIDGET_H
+#define PROFILECHANGERWIDGET_H
 
-#include <QMainWindow>
 #include <QDBusInterface>
 #include <qmaemo5homescreenadaptor.h>
 #include <QErrorMessage>
@@ -12,12 +11,12 @@ namespace Ui {
     class ProfileChangerWidget;
 }
 
-class ProfileChangerWidget : public QMainWindow
+class ProfileChangerWidget : public QWidget
 {
     Q_OBJECT
 
 public:
-    explicit ProfileChangerWidget (QWidget *parent = 0);
+    explicit ProfileChangerWidget(QWidget *parent = 0);
     ~ProfileChangerWidget();
 
 
@@ -38,5 +37,5 @@ private:
     void refreshIcon();
 };
 
-#endif // _PROFILECHANGERWIDGET_H_
+#endif // PROFILECHANGERWIDGET_H
 
